@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2013, Mahmoud Hashemi
 #
 # Redistribution and use in source and binary forms, with or without
@@ -56,26 +54,12 @@ import re
 import time
 import bisect
 import operator
-from datetime import tzinfo, timedelta, date, datetime
+from datetime import tzinfo, timedelta, date, datetime, timezone
 
 
-def total_seconds(td):
-    """For those with older versions of Python, a pure-Python
-    implementation of Python 2.7's :meth:`~datetime.timedelta.total_seconds`.
-
-    Args:
-        td (datetime.timedelta): The timedelta to convert to seconds.
-    Returns:
-        float: total number of seconds
-
-    >>> td = timedelta(days=4, seconds=33)
-    >>> total_seconds(td)
-    345633.0
-    """
-    a_milli = 1000000.0
-    td_ds = td.seconds + (td.days * 86400)  # 24 * 60 * 60
-    td_micro = td.microseconds + (td_ds * a_milli)
-    return td_micro / a_milli
+# For legacy compatibility.
+# boltons used to offer an implementation of total_seconds for Python <2.7
+total_seconds = timedelta.total_seconds
 
 
 def dt_to_timestamp(dt):
@@ -85,7 +69,9 @@ def dt_to_timestamp(dt):
 
     .. _Epoch-based timestamps: https://en.wikipedia.org/wiki/Unix_time
 
-    >>> abs(round(time.time() - dt_to_timestamp(datetime.utcnow()), 2))
+    >>> timestamp = int(time.time())
+    >>> utc_dt = datetime.fromtimestamp(timestamp, timezone.utc)
+    >>> timestamp - dt_to_timestamp(utc_dt)
     0.0
 
     ``dt_to_timestamp`` supports both timezone-aware and naïve
@@ -101,8 +87,8 @@ def dt_to_timestamp(dt):
     if dt.tzinfo:
         td = dt - EPOCH_AWARE
     else:
-        td = dt - EPOCH_NAIVE
-    return total_seconds(td)
+        td = dt.replace(tzinfo=timezone.utc) - EPOCH_AWARE
+    return timedelta.total_seconds(td)
 
 
 _NONDIGIT_RE = re.compile(r'\D')
@@ -147,8 +133,8 @@ _BOUND_DELTAS = [b[0] for b in _BOUNDS]
 
 _FLOAT_PATTERN = r'[+-]?\ *(\d+(\.\d*)?|\.\d+)([eE][+-]?\d+)?'
 _PARSE_TD_RE = re.compile(r"((?P<value>%s)\s*(?P<unit>\w)\w*)" % _FLOAT_PATTERN)
-_PARSE_TD_KW_MAP = dict([(unit[0], unit + 's')
-                         for _, _, unit in reversed(_BOUNDS[:-2])])
+_PARSE_TD_KW_MAP = {unit[0]: unit + 's'
+                         for _, _, unit in reversed(_BOUNDS[:-2])}
 
 
 def parse_timedelta(text):
@@ -239,11 +225,11 @@ def decimal_relative_time(d, other=None, ndigits=0, cardinalize=True):
     if other is None:
         other = datetime.utcnow()
     diff = other - d
-    diff_seconds = total_seconds(diff)
+    diff_seconds = timedelta.total_seconds(diff)
     abs_diff = abs(diff)
     b_idx = bisect.bisect(_BOUND_DELTAS, abs_diff) - 1
     bbound, bunit, bname = _BOUNDS[b_idx]
-    f_diff = diff_seconds / total_seconds(bunit)
+    f_diff = diff_seconds / timedelta.total_seconds(bunit)
     rounded_diff = round(f_diff, ndigits)
     if cardinalize:
         return rounded_diff, _cardinalize_time_unit(bname, abs(rounded_diff))
@@ -279,7 +265,7 @@ def relative_time(d, other=None, ndigits=0):
     phrase = 'ago'
     if drt < 0:
         phrase = 'from now'
-    return '%g %s %s' % (abs(drt), unit, phrase)
+    return f'{abs(drt):g} {unit} {phrase}'
 
 
 def strpdate(string, format):
@@ -420,7 +406,7 @@ class ConstantTZInfo(tzinfo):
 
     @property
     def utcoffset_hours(self):
-        return total_seconds(self.offset) / (60 * 60)
+        return timedelta.total_seconds(self.offset) / (60 * 60)
 
     def utcoffset(self, dt):
         return self.offset
@@ -433,12 +419,11 @@ class ConstantTZInfo(tzinfo):
 
     def __repr__(self):
         cn = self.__class__.__name__
-        return '%s(name=%r, offset=%r)' % (cn, self.name, self.offset)
+        return f'{cn}(name={self.name!r}, offset={self.offset!r})'
 
 
 UTC = ConstantTZInfo('UTC')
 EPOCH_AWARE = datetime.fromtimestamp(0, UTC)
-EPOCH_NAIVE = datetime.utcfromtimestamp(0)
 
 
 class LocalTZInfo(tzinfo):
